@@ -70,18 +70,26 @@ def read_csv_values(file_name, convert=False, delimiter=',', quotechar='|'):
                 pass
         return s
 
-    # open the file in universal line ending mode
-    with open(file_name, newline='') as infile:
-        # read the file as a dictionary for each row ({header : value})
-        reader = csv.DictReader(
-            infile, delimiter=delimiter, quotechar=quotechar)
-        data = dict()
-        for row in reader:
-            for header, value in row.items():
-                try:
-                    data[header].append(_convert(value))
-                except KeyError:
-                    data[header] = [_convert(value)]
+    try:
+        infile = None
+        with open(file_name, newline='') as infile:
+            # read the file as a dictionary for each row ({header : value})
+            reader = csv.DictReader(
+                infile, delimiter=delimiter, quotechar=quotechar)
+            data = dict()
+            for row in reader:
+                for header, value in row.items():
+                    try:
+                        data[header].append(_convert(value))
+                    except KeyError:
+                        data[header] = [_convert(value)]
+    except FileNotFoundError as ex:
+        raise ex
+    except IOError:
+        return None
+    finally:
+        if infile:
+            infile.close()
     return data
 
 
